@@ -55,8 +55,8 @@ sub decode {
             # does the string start with the bom?
             if ($bom eq substr($data, 0, length($bom))) {
                 # decode it and hand it back
-                return Encode::decode($enc, $data);
-                return Encode::decode($enc, substr($data, length($bom)));
+#                return Encode::decode($enc, $data);
+                return Encode::decode($enc, substr($data, length($bom)), 1);
             }
         }
         return $data;
@@ -165,11 +165,11 @@ Unicode data. Internally it calls the L<decode()> method.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
 
 =head1 SEE ALSO
 
