@@ -421,30 +421,29 @@ sub chmod_path {
     my $path = $self->definitive_write(shift);
     chmod(shift, $path);
 }
-    
+
 
 #-----------------------------------------------------------------------
 # file manipulation methods
 #-----------------------------------------------------------------------
 
 sub create_file {
-    my $self = shift;
-    my $path = $self->definitive_write(shift);
-    unless (-e $path) {
-        $self->write_file($path);
+    my ($self, $path) = @_;
+    unless (-e $self->definitive_write($path)) {
+        $self->write_file($path); # calls definitive_write again
     }
     return 1;
 }
 
 sub touch_file {
-    my $self = shift;
-    my $path = $self->definitive_write(shift);
-    if (-e $path) {
+    my ($self, $path) = @_;
+    my $definitive = $self->definitive_write($path);
+    if (-e $definitive) {
         my $now = time();
-        utime $now, $now, $path;
-    } 
+        utime $now, $now, $definitive;
+    }
     else {
-        $self->write_file($path);
+        $self->write_file($path); # calls definitive_write again
     }
 }
 
@@ -539,14 +538,33 @@ sub _file_copy {
 
     my $file;
 
-    unless (ref $dest) {
-        # NOTE: don't use $self->file($dest) because $self could be a 
+   unless (ref $dest) {
+        # NOTE: don't use $self->file($dest) because $self could be a
         # VFS and $dest is already a definitive path
         $file = File($dest);
-        $file->directory->must_exist(
-            $params->{ mkdir    },
-            $params->{ dir_mode },
-        );
+        # capture our current working directory
+        my $cwd = cwd;
+        eval {
+            # Change to the destination volume if one exists.
+            # Should work for any volume except Windows shares
+            # where resulting behavior is version dependent.
+            chdir $file->volume if ($file->volume);
+            # this code strips volume information
+            $file->directory->must_exist(
+                $params->{ mkdir    },
+                $params->{ dir_mode },
+            );
+            # change back to the current working directory
+            chdir $cwd;
+        } or do {
+            # capture any exception from above
+            # change back to the oringial cwd
+            # and rethrow the execption.
+            if ($@) {
+                chdir $cwd;
+                die $@;
+            }
+        }
     }
 
     $code->($src, $dest)
